@@ -54,7 +54,7 @@ SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVarian
 }
 
 SKGImportPluginBackend::~SKGImportPluginBackend()
-{}
+    = default;
 
 QExplicitlySharedDataPointer<KService> SKGImportPluginBackend::getService() const
 {
@@ -76,8 +76,6 @@ QString SKGImportPluginBackend::getParameter(const QString& iAttribute)
         QString param = "parameter" + SKGServices::intToString(i);
         if (output.contains(QStringLiteral("%") % param)) {
             output = output.replace(QStringLiteral("%") % param, parameters.value(param));
-        } else {
-            break;
         }
     }
 
@@ -101,24 +99,37 @@ struct download {
     QString operator()(const QString& iAccountId)
     {
         QString file = m_path % "/" % iAccountId % ".csv";
+        // Build cmd
+        QString cmd = m_cmd;
+        cmd = cmd.replace(QStringLiteral("%2"), SKGServices::intToString(m_nbToDownload)).replace(QStringLiteral("%1"), iAccountId).replace(QStringLiteral("%3"), m_pwd).replace(QStringLiteral("%4"), m_date);
+
+        // Execute
+        QProcess p;
+        cmd = SKGServices::getFullPathCommandLine(cmd);
+        SKGTRACEL(10) << "Execute: " << cmd << endl;
+        p.setStandardOutputFile(file);
+
         int retry = 0;
         do {
-            // Build cmd
-            QString cmd = m_cmd;
-            cmd = cmd.replace(QStringLiteral("%2"), SKGServices::intToString(m_nbToDownload)).replace(QStringLiteral("%1"), iAccountId).replace(QStringLiteral("%3"), m_pwd).replace(QStringLiteral("%4"), m_date);
-
-            // Execute
-            QProcess p;
-            SKGTRACEL(10) << "Execute: " << cmd << endl;
-            p.setStandardOutputFile(file);
             p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
-            if (p.waitForFinished(1000 * 60 * 2) && p.exitCode() == 0) {
-                return iAccountId;
+            if (p.waitForFinished(1000 * 60 * 2)) {
+                if (p.exitCode() == 0) {
+                    return iAccountId;
+                } else {
+                    SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << endl;
+                }
+            } else {
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << endl;
+                p.terminate();
+                p.kill();
             }
             ++retry;
         } while (retry < 6);
 
-        return QStringLiteral("");
+        QString errorMsg = i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode());
+        SKGTRACE << errorMsg << endl;
+
+        return QStringLiteral("ERROR:") + errorMsg;
     }
 
     int m_nbToDownload;
@@ -146,9 +157,11 @@ SKGError SKGImportPluginBackend::importFile()
     // Get list of accounts
     QStringList backendAccounts;
     QMap<QString, QString> backendAccountsBalance;
+    QMap<QString, QString> backendAccountsName;
     QString csvfile = m_tempDir.path() % "/skrooge_backend.csv";
     QString cmd = getParameter(QStringLiteral("X-SKROOGE-getaccounts")).replace(QStringLiteral("%3"), pwd);
     QProcess p;
+    cmd = SKGServices::getFullPathCommandLine(cmd);
     SKGTRACEL(10) << "Execute: " << cmd << endl;
     p.setStandardOutputFile(csvfile);
     p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
@@ -161,6 +174,7 @@ SKGError SKGImportPluginBackend::importFile()
         } else {
             QRegExp reggetaccounts(getParameter(QStringLiteral("X-SKROOGE-getaccountid")));
             QRegExp reggetaccountbalance(getParameter(QStringLiteral("X-SKROOGE-getaccountbalance")));
+            QRegExp reggetaccountname(getParameter(QStringLiteral("X-SKROOGE-getaccountname")));
 
             QTextStream stream(&file);
             stream.readLine();  // To avoid header
@@ -187,6 +201,14 @@ SKGError SKGImportPluginBackend::importFile()
                         } else {
                             backendAccountsBalance[accountid] = '0';
                         }
+
+                        // Get account name
+                        pos = reggetaccountname.indexIn(line);
+                        if (pos > -1) {
+                            backendAccountsName[accountid] = reggetaccountname.cap(1);
+                        } else {
+                            backendAccountsName[accountid] = "";
+                        }
                     }
                 } else {
                     // This is an error
@@ -231,6 +253,7 @@ SKGError SKGImportPluginBackend::importFile()
                 SKGTRACEL(10) << "Mode getbulk" << endl;
                 QProcess pbulk;
                 QString cmd = bulk.replace(QStringLiteral("%1"), m_tempDir.path());
+                cmd = SKGServices::getFullPathCommandLine(cmd);
                 cmddownload = cmd;
                 SKGTRACEL(10) << "Execute: " << cmd << endl;
                 pbulk.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
@@ -255,19 +278,31 @@ SKGError SKGImportPluginBackend::importFile()
                 listDownloadedId = f.results();
             }
             listDownloadedId.removeAll(QStringLiteral(""));
+            // Build list of errors
+            QStringList errors;
+            int nb = listDownloadedId.count();
+            errors.reserve(nb);
+            for (int i = nb - 1; i >= 0; --i) {
+                auto item = listDownloadedId.value(i);
+                if (item.startsWith(QLatin1String("ERROR:"))) {
+                    listDownloadedId.removeAt(i);
+                    errors.push_back(item.right(item.length() - 6));
+                }
+            }
 
             // Check
             IFOK(err) {
                 bool checkOK = true;
                 int nb = listDownloadedId.count();
-                if (100 * nb / backendAccounts.count() < 80) {
+                if (errors.count()) {
                     // Some accounts have not been downloaded
                     if (nb == 0) {
                         err = SKGError(ERR_FAIL, i18nc("Error message", "No accounts downloaded with the following command:\n%1\nCheck your backend installation.", cmddownload));
                     } else {
                         // Warning
-                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded"), SKGDocument::Warning);
+                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded. %1", errors.join(QStringLiteral(". "))), SKGDocument::Warning);
                     }
+                    SKGTRACEL(10) << errors.count() << " accounts not imported => checkOK=false" << endl;
                     checkOK = false;
                 }
 
@@ -283,8 +318,16 @@ SKGError SKGImportPluginBackend::importFile()
 
                     // Import all files
                     for (int i = 0; !err && i < nb; ++i) {
-                        // Import
+                        // Rename the imported name
                         QString file = m_tempDir.path() % "/" % listDownloadedId.at(i) % ".csv";
+                        if (!listDownloadedId.at(i).contains(QStringLiteral("-")) && !backendAccountsName[listDownloadedId.at(i)].isEmpty()) {
+                            QString newFileName = m_tempDir.path() % "/" % backendAccountsName[listDownloadedId.at(i)] % '-' % listDownloadedId.at(i) % ".csv";
+                            if (QFile::rename(file, newFileName)) {
+                                file = newFileName;
+                            }
+                        }
+
+                        // Import
                         SKGImportExportManager imp1(m_importer->getDocument(), QUrl::fromLocalFile(file));
                         imp1.setAutomaticValidation(m_importer->automaticValidation());
                         imp1.setAutomaticApplyRules(m_importer->automaticApplyRules());
@@ -300,25 +343,14 @@ SKGError SKGImportPluginBackend::importFile()
                         newParameters[QStringLiteral("mode_csv_unit")] = 'N';
                         newParameters[QStringLiteral("mode_csv_rule")] = 'N';
                         newParameters[QStringLiteral("balance")] = backendAccountsBalance[listDownloadedId.at(i)];
-                        if (i != nb - 1) {
-                            newParameters[QStringLiteral("donotfinalize")] = 'Y';
-                        }
+                        newParameters[QStringLiteral("donotfinalize")] = 'Y';
                         imp1.setImportParameters(newParameters);
                         IFOKDO(err, imp1.importFile())
 
                         if (!backendAccountsBalance[listDownloadedId.at(i)].isEmpty()) {
                             SKGAccountObject act;
                             IFOKDO(err, imp1.getDefaultAccount(act));
-
-                            // Compute if at least one reconciliation is possible
-                            auto targetBalance = SKGServices::stringToDouble(backendAccountsBalance[listDownloadedId.at(i)]);
-
-                            m_importer->addAccountToCheck(act, targetBalance);
-
-                            auto soluces = act.getPossibleReconciliations(targetBalance, false);
-                            if (soluces.isEmpty()) {
-                                checkOK = false;
-                            }
+                            m_importer->addAccountToCheck(act, SKGServices::stringToDouble(backendAccountsBalance[listDownloadedId.at(i)]));
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
@@ -337,6 +369,28 @@ SKGError SKGImportPluginBackend::importFile()
                         m_importer->getDocument()->sendMessage(msg.Text, msg.Type, msg.Action);
                     }
 
+                    // Finalize import
+                    IFOKDO(err, m_importer->finalizeImportation())
+
+                    // Disable std finalisation
+                    QMap<QString, QString> parameters = m_importer->getImportParameters();
+                    parameters[QStringLiteral("donotfinalize")] = 'Y';
+                    m_importer->setImportParameters(parameters);
+
+                    // Check balances of accounts
+                    auto accountsToCheck = m_importer->getAccountsToCheck();
+                    int nb = accountsToCheck.count();
+                    for (int i = 0; !err && i < nb; ++i) {
+                        // Get the account to check
+                        auto act = accountsToCheck[i].first;
+                        auto targetBalance = accountsToCheck[i].second;
+                        auto soluces = act.getPossibleReconciliations(targetBalance, false);
+                        if (soluces.isEmpty()) {
+                            SKGTRACEL(10) << "Account " << listDownloadedId.at(i) << " not reconciliable => checkOK=false" << endl;
+                            checkOK = false;
+                        }
+                    }
+
                     if (checkOK) {
                         // Last import is memorized only in case of 100% success
                         IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE", SKGServices::dateToSqlString(QDateTime::currentDateTime())))
