@@ -54,25 +54,25 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGImportPluginKmy();
+    ~SKGImportPluginKmy() override;
 
     /**
      * To know if import is possible with this plugin
      */
-    virtual bool isImportPossible() override;
+    bool isImportPossible() override;
 
     /**
      * Import a file
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError importFile() override;
+    SKGError importFile() override;
 
     /**
      * To know if export is possible with this plugin
      * @return true or false
      */
-    virtual bool isExportPossible() override;
+    bool isExportPossible() override;
 
 
     /**
@@ -80,13 +80,13 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError exportFile() override;
+    SKGError exportFile() override;
 
     /**
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual QString getMimeTypeFilter() const override;
+    QString getMimeTypeFilter() const override;
 
 private:
     Q_DISABLE_COPY(SKGImportPluginKmy)
