@@ -26,7 +26,6 @@
 #include <kpluginfactory.h>
 
 #include <qdom.h>
-#include <qfileinfo.h>
 
 #include "skgtraces.h"
 #include "skgservices.h"
@@ -48,8 +47,7 @@ SKGImportPluginXhb::SKGImportPluginXhb(QObject* iImporter, const QVariantList& i
 }
 
 SKGImportPluginXhb::~SKGImportPluginXhb()
-{
-}
+    = default;
 
 bool SKGImportPluginXhb::isImportPossible()
 {
