@@ -118,20 +118,34 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         QStringList items = fInfo.baseName().split('@');
         QString bankname;
         QString number;
+        QString nameComplete;
         QString name = items.at(0);
         if (items.count() == 2) {
             bankname = items.at(1);
+
+            QStringList items2 = name.split('-');
+            if (items2.count() == 2) {
+                name = items2.at(0);
+                number = items2.at(1);
+            } else {
+                number = name;
+            }
+
+            name.replace('_', ' ');
+            name.replace('-', ' ');
+            nameComplete = name;
         } else {
             bankname = name;
-        }
-        name.replace('_', ' ');
-        name.replace('-', ' ');
-        QString nameComplete = name;
-        QRegExp rx(QStringLiteral("(\\d{6,})"));
-        if (rx.indexIn(name) != -1) {
-            number = rx.cap(1);
-            if (name != number) {
-                name = name.remove(number).trimmed();
+
+            name.replace('_', ' ');
+            name.replace('-', ' ');
+            nameComplete = name;
+            QRegExp rx(QStringLiteral("(\\d{6,})"));
+            if (rx.indexIn(name) != -1) {
+                number = rx.cap(1);
+                if (name != number) {
+                    name = name.remove(number).trimmed();
+                }
             }
         }
 
