@@ -830,7 +830,7 @@ bool SKGUnitObject::isWritable(const QString& iSource)
     return QFileInfo(fileName).isWritable();
 }
 
-SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValues, bool iAdditionalInfo)
+SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValues)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
@@ -845,7 +845,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
         // Get last date
         QDate firstDate;
         SKGStringListList result;
-        doc->executeSelectSqliteOrder("SELECT MAX(d_date) FROM unitvalue where rd_unit_id=(SELECT id from unit where t_name='" % SKGServices::stringToSqlString(unitname) % "')", result);
+        doc->executeSelectSqliteOrder("SELECT MAX(d_date) FROM unitvalue where rd_unit_id=" % SKGServices::intToString(getID()), result);
         if (result.count() == 2) {
             firstDate = SKGServices::stringToTime(result.at(1).at(0)).date().addDays(-1);
         }
@@ -892,10 +892,14 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 IFOKDO(err, val.setQuantity(value))
                 IFOKDO(err, val.save())
             }
-        } else if (source.isEmpty() || source == i18nc("Native download source (Yahoo)", "Yahoo")) {
-            // NATIVE MODE
-            // Example of code: DSY.PA
-            // https://query1.finance.yahoo.com/v7/finance/download/^DSY.PA?period1=1493407730&period2=1495999730&interval=1d&events=history&crumb=MSkpboM9ZkK
+        } else {
+            // Quote download
+
+            // Set 1st january 1970 if date is not found
+            if (!firstDate.isValid()) {
+                firstDate.setDate(1970, 1, 1);
+            }
+
             QString interval = QStringLiteral("1d");
             bool last = (iMode == LAST);
             if (last) {
@@ -917,288 +921,6 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 interval = QStringLiteral("1d");
             }
 
-            // Download history
-            if (!last) {
-                QStringList args = QStringList() << code << firstDate.toString(QStringLiteral("yyyyMMdd")) << QDate::currentDate().toString(QStringLiteral("yyyyMMdd")) << interval;
-
-                SKGError err2;
-                QProcess p;
-                int failure = 0;
-                do {
-                    p.start(QStringLiteral("skrooge-yahoodl.py"), args);
-                    if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) {
-                        QString cmd = "skrooge-yahoodl.py " % args.join(QStringLiteral(" "));
-                        err2.setReturnCode(ERR_FAIL).setMessage(p.readAll());
-                        err2.addError(ERR_FAIL, i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
-                        ++failure;
-                    }
-                } while (err2 && failure < 5);
-
-                if (!err2) {
-                    // The file is something like this
-                    // Date,Open,High,Low,Close,Adj Close,Volume
-                    // 2017-01-02,4845.959961,4896.009766,4843.930176,4882.379883,4882.379883,34310400
-                    // 2017-01-03,4904.770020,4929.600098,4896.109863,4899.330078,4899.330078,82609500
-                    // 2017-01-04,4912.950195,4913.939941,4879.229980,4899.399902,4899.399902,77276800
-                    // 2017-01-05,4881.720215,4905.839844,4874.790039,4900.640137,4900.640137,88092000
-                    // 2017-01-06,4885.189941,4911.490234,4874.419922,4909.839844,4909.839844,73709000
-
-                    QStringList lines = SKGServices::splitCSVLine(p.readAll(), '\n');
-                    int nb = lines.count();
-                    for (int i = 1; i < nb && !err2 && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) {  // -1 because the value of the day will be loaded after
-                        // Read line
-                        QString line = lines.at(i);
-                        QStringList fields = SKGServices::splitCSVLine(line, ',');
-                        if (fields.count() != 7) {
-                            err2.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.", line));
-                        } else {
-                            if (fields[5] != QLatin1String("null")) {
-                                QDate ds = QDate::fromString(fields[0], QStringLiteral("yyyy-MM-dd"));
-                                double val = SKGServices::stringToDouble(fields[5]);
-
-                                // Creation or update of the value
-                                SKGUnitValueObject value;
-                                if (!err2) {
-                                    err2 = addUnitValue(value);
-                                }
-                                if (!err2) {
-                                    err2 = value.setDate(ds);
-                                }
-                                if (!err2) {
-                                    err2 = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                }
-                                if (!err2) {
-                                    err2 = value.save();
-                                }
-                            }
-                        }
-                    }
-                } else {
-                    // 283840: doc->sendMessage(KIO::NetAccess::lastErrorString());
-                    doc->sendMessage(i18nc("A warning message", "History for %1 not found on Yahoo", code), SKGDocument::Warning);
-                    SKGTRACE << "WARNING: skrooge-yahoodl.py failed. " << err2.getFullMessageWithHistorical() << endl;
-                }
-            }
-            IFOK(err) {
-                // Build list of additional download information
-                // http://www.etraderzone.com/free-scripts/50-yahoo-stock-quotes.html?catid=34%3Aexcel-script
-                QStringList unitYahooCode;
-                QStringList unitYahooTitle;
-                QString yahooString;
-                if (iAdditionalInfo) {
-                    unitYahooCode.push_back(QStringLiteral("a"));  // 1
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask"));
-                    unitYahooCode.push_back(QStringLiteral("a2"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Average Daily Volume"));
-                    // Sometimes contains a , ==> KO: unitYahooCode.push_back("a5");
-                    // Sometimes contains a , ==> KO: unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask Size"));
-                    unitYahooCode.push_back(QStringLiteral("b"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid"));
-                    unitYahooCode.push_back(QStringLiteral("b4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Book Value"));
-                    // Can block due to , unitYahooCode.push_back("b6");
-                    // Can block due to , unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid Size"));
-                    // unitYahooCode.push_back("c");
-                    // unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "% Change"));
-                    unitYahooCode.push_back(QStringLiteral("c1"));  // 10
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change"));
-                    unitYahooCode.push_back(QStringLiteral("c3"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Commission"));
-                    unitYahooCode.push_back(QStringLiteral("d"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend/Share"));
-                    unitYahooCode.push_back(QStringLiteral("d2"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Trade Date"));
-                    unitYahooCode.push_back(QStringLiteral("e"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Earning/Share"));
-                    // unitYahooCode.push_back("e1");
-                    // unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Error Indication"));
-                    unitYahooCode.push_back(QStringLiteral("e7"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Current Year"));
-                    unitYahooCode.push_back(QStringLiteral("e8"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Next Year"));
-                    unitYahooCode.push_back(QStringLiteral("e9"));  // 20
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EPS Estimate Next Quarter"));
-                    // unitYahooCode.push_back("f6");
-                    // unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Float Shares"));
-                    unitYahooCode.push_back(QStringLiteral("g1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain %"));
-                    unitYahooCode.push_back(QStringLiteral("g3"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Annualized Gain"));
-                    unitYahooCode.push_back(QStringLiteral("g4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain"));
-                    unitYahooCode.push_back(QStringLiteral("i"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "More Info"));
-                    unitYahooCode.push_back(QStringLiteral("j1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Market Capitalization"));
-                    unitYahooCode.push_back(QStringLiteral("j4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "EBITDA"));
-                    unitYahooCode.push_back(QStringLiteral("j5"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 52 weeks Low"));
-                    unitYahooCode.push_back(QStringLiteral("j6"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
-                                                   // xgettext: no-c-format
-                                                   "% Change from 52 weeks Low"));
-                    unitYahooCode.push_back(QStringLiteral("k3"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade Size"));
-                    unitYahooCode.push_back(QStringLiteral("k4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 52 weeks High"));
-                    unitYahooCode.push_back(QStringLiteral("k5"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
-                                                   // xgettext: no-c-format
-                                                   "% Change from 52 weeks"));
-                    // unitYahooCode.push_back("l");
-                    // unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade with Time"));
-                    unitYahooCode.push_back(QStringLiteral("l2"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "High Limit"));
-                    unitYahooCode.push_back(QStringLiteral("l3"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Low Limit"));
-                    unitYahooCode.push_back(QStringLiteral("m"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Range"));
-                    unitYahooCode.push_back(QStringLiteral("m3"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "50 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("m4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "200 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("m5"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 200 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("m6"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
-                                                   // xgettext: no-c-format
-                                                   "% Change from 200 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("m7"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change from 50 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("m8"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share",
-                                                   // xgettext: no-c-format
-                                                   "% Change from 50 days MA"));
-                    unitYahooCode.push_back(QStringLiteral("n4"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Notes"));
-                    unitYahooCode.push_back(QStringLiteral("o"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Open"));
-                    unitYahooCode.push_back(QStringLiteral("p"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Previous Close"));
-                    unitYahooCode.push_back(QStringLiteral("p1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price Paid"));
-                    unitYahooCode.push_back(QStringLiteral("p2"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change in %"));
-                    unitYahooCode.push_back(QStringLiteral("p5"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/Sales"));
-                    unitYahooCode.push_back(QStringLiteral("p6"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/Book"));
-                    unitYahooCode.push_back(QStringLiteral("q"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ex-Dividend Date"));
-                    unitYahooCode.push_back(QStringLiteral("r"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "P/E Ratio"));
-                    unitYahooCode.push_back(QStringLiteral("r1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend Pay Date"));
-                    unitYahooCode.push_back(QStringLiteral("r5"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "PEG Ratio"));
-                    unitYahooCode.push_back(QStringLiteral("r6"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/EPS Estimate Current Year"));
-                    unitYahooCode.push_back(QStringLiteral("r7"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Price/EPS Estimate Next Year"));
-                    // unitYahooCode.push_back("s");
-                    // unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Symbol"));
-                    unitYahooCode.push_back(QStringLiteral("s1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Shares Owned"));
-                    unitYahooCode.push_back(QStringLiteral("s7"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Short Ratio"));
-                    unitYahooCode.push_back(QStringLiteral("t1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade Time"));
-                    unitYahooCode.push_back(QStringLiteral("t8"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "1 Year Target"));
-                    unitYahooCode.push_back(QStringLiteral("v"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Volume"));
-                    unitYahooCode.push_back(QStringLiteral("v1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Value"));
-                    unitYahooCode.push_back(QStringLiteral("w"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "52 weeks Range"));
-                    unitYahooCode.push_back(QStringLiteral("w1"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Value Change"));
-                    unitYahooCode.push_back(QStringLiteral("x"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Stock Exchange"));
-                    unitYahooCode.push_back(QStringLiteral("y"));
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Dividend Yield"));
-                    unitYahooCode.push_back(QStringLiteral("n"));  // Must be the last
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Name"));
-
-                    /*unitYahooCode.push_back("c6");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change (RT)"));
-                    unitYahooCode.push_back("c8");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "After Hour Change (RT)"));
-                    unitYahooCode.push_back("g5");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain % (RT)"));
-                    unitYahooCode.push_back("g6");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Gain (RT)"));
-                    unitYahooCode.push_back("i5");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Order Book (RT)"));
-                    unitYahooCode.push_back("j3");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Market Cap (RT)"));
-                    unitYahooCode.push_back("k1");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Last Trade with Time (RT)"));
-                    unitYahooCode.push_back("k2");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Change % (RT)"));
-                    unitYahooCode.push_back("r2");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "P/E Ratio (RT)"));
-                    unitYahooCode.push_back("b2");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Ask (RT)"));
-                    unitYahooCode.push_back("b3");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Bid (RT)"));
-                    unitYahooCode.push_back("v7");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Holding Value (RT)"));
-                    unitYahooCode.push_back("m2");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Range (RT)"));
-                    unitYahooCode.push_back("w4");
-                    unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Value Change (RT)"));*/
-
-                    for (const auto& key : qAsConst(unitYahooCode)) {
-                        yahooString += key;
-                    }
-
-                    // Add yahoo url
-                    err = setProperty(i18nc("Yahoo title for a downloaded information of a share", "Yahoo page"), "http://finance.yahoo.com/q?s=" % code);
-                }
-
-                // http://download.finance.yahoo.com/d/quotes.csv?s=DSY.PA&f=l1d1
-                QString path = "http://download.finance.yahoo.com/d/quotes.csv?s=" % code % "&f=l1d1" % yahooString;  // l1=val d1=date
-                QByteArray stream;
-                SKGError errTmp = SKGServices::downloadToStream(QUrl(path), stream);
-                if (!errTmp) {
-                    // Read line
-                    QString line = stream.trimmed();
-                    QStringList fields = SKGServices::splitCSVLine(line, ',');
-                    QDate ds;
-                    int nb = fields.count();
-                    if (nb != unitYahooTitle.count() + 2) {
-                        err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line), SKGDocument::Warning);
-
-                        IFOKDO(err, downloadUnitValue(iMode, nbMaxValues, false))
-                    } else {
-                        if ((ds = QDate::fromString(fields[1], QStringLiteral("M/d/yyyy"))).isValid()) {
-                            double val = SKGServices::stringToDouble(fields[0]);
-
-                            // Creation or update of the value
-                            SKGUnitValueObject value;
-                            IFOKDO(err, addUnitValue(value))
-                            IFOKDO(err, value.setDate(ds))
-                            IFOKDO(err, value.setQuantity(invert && val != 0 ? 1 / val : val))
-                            IFOKDO(err, value.save())
-                        } else {
-                            err.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
-                        }
-
-                        for (int j = 2; !err && j < nb; ++j) {
-                            QString val = fields.at(j);
-                            if (!val.contains(QStringLiteral("N/A")) && val != QStringLiteral("-") && val != QStringLiteral("- - -") && val != QStringLiteral("0") && val != QStringLiteral("0.00")) {
-                                err = setProperty(unitYahooTitle[j - 2], val);
-                            }
-                        }
-                    }
-                } else {
-                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, errTmp.getFullMessageWithHistorical()), SKGDocument::Warning);
-                }
-            }
-        } else {
-            // ALTERNATIVE MODE
             QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/quotes/" % source % ".txt");
             if (fileName.isEmpty()) {
                 err = SKGError(ERR_FAIL, i18nc("Error message", "Source of download %1 is not installed.", source));
@@ -1221,7 +943,8 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     QString dateFormat = properties[QStringLiteral("dateformat")];
 
                     path = path.replace(QStringLiteral("%2"), QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd")));
-                    path = path.replace(QStringLiteral("%3"), QDate::currentDate().addDays(-nbMaxValues).toString(QStringLiteral("yyyy-MM-dd")));
+                    path = path.replace(QStringLiteral("%3"), firstDate.toString(QStringLiteral("yyyy-MM-dd")));
+                    path = path.replace(QStringLiteral("%4"), interval);
 
 
                     SKGTRACEL(1) << "path=[" << path << "]" << endl;
@@ -1233,6 +956,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     // Download url
                     QByteArray stream;
                     if (modeScript) {
+                        path = SKGServices::getFullPathCommandLine(path);
+                        SKGTRACEL(1) << "full path=[" << path << "]" << endl;
+
                         QProcess p;
                         p.start(path);
                         if (p.waitForFinished(1000 * 60 * 2) && p.exitCode() == 0) {
@@ -1253,7 +979,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                         QStringList lines = (mode.startsWith(QLatin1String("CSV")) ? SKGServices::splitCSVLine(stream, '\n') : QStringList() << QStringLiteral("") << stream);
                         int nb = lines.count();
                         int nbLoaded = 0;
-                        for (int i = 1; i < nb && !err && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) {  // -1 because the value of the day will be loaded after
+                        for (int i = 1; i < nb && !err && (i < nbMaxValues || nbMaxValues == 0); ++i) {
                             QString data = lines.at(mode == QStringLiteral("CSVR") ? nb - i : i).trimmed();
                             if (!data.isEmpty()) {
                                 SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
@@ -1298,6 +1024,10 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                     IFOKDO(err, value.setQuantity(invert && val != 0 ? 1 / val : val))
                                     IFOKDO(err, value.save())
 
+                                    if (last) {
+                                        break;
+                                    }
+
                                     nbLoaded++;
                                 }
                             }
