@@ -59,7 +59,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGGraphicsView();
+    ~SKGGraphicsView() override;
 
 public Q_SLOTS:
     /**
@@ -167,7 +167,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void showMenu(const QPoint iPos);
