@@ -57,14 +57,13 @@ public:
      * Default Constructor
      * @param iSplashScreen the splash screen
      * @param iDocument the document to manage data
-     * @param iArguments the arguments
      */
-    explicit SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument, const QStringList& iArguments);
+    explicit SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument);
 
     /**
      * Default Destructor
      */
-    virtual ~SKGMainPanel();
+    ~SKGMainPanel() override;
 
     /**
      * Return the document of the main panel
@@ -193,7 +192,7 @@ public Q_SLOTS:
      * To know if the closure of the application is authorized
      * @return true if close is authorized else false
      */
-    virtual bool queryClose() override;
+    bool queryClose() override;
 
     /**
      * To know if the closure of the file is authorized
@@ -379,6 +378,8 @@ public Q_SLOTS:
      * @param iAction action pointer
      * @param iAddInCollection to add or not the action in the main panel collection
      * @param iListOfTable list of table where this action must be enabled (empty list means all)
+     *                 You can also add only one item like this to set the list dynamically:
+     *                 query:the sql condition on sqlite_master
      * @param iMinSelection the minimum number of selected item to enable the action
      *                  0 : no need selection but need a page opened containing a table
      *                 -1 : no need selection and need a page opened (not containing a table)
@@ -408,7 +409,6 @@ public Q_SLOTS:
      */
     virtual void unRegisterGlobalAction(QObject* iAction);
 
-
     /**
      * Get a registered global action
      * @param iIdentifier identifier of the action
@@ -431,10 +431,17 @@ public Q_SLOTS:
     virtual QMap<QString, QPointer<QAction> > getGlobalActions() const;
 
     /**
-     * Get the temporary filename containing the tips of days
-     * @return the file name
+     * Get the tips of days
+     * @return the tips of days
      */
-    virtual QString getTipOfDayFileName();
+    virtual QStringList getTipsOfDay() const;
+
+    /**
+     * Get the tip of days
+     * @return the tip of days
+     */
+    virtual QString getTipOfDay() const;
+
     /**
      * Define if the document must be saved when closed
      * @param iSaveOnClose the save on close mode
@@ -495,14 +502,14 @@ protected:
      * event
      * @param e event
      */
-    virtual void changeEvent(QEvent* e) override;
+    void changeEvent(QEvent* e) override;
     /**
      * Event filtering
      * @param iObject object
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void showMenu(const QPoint iPos);
@@ -513,7 +520,6 @@ private Q_SLOTS:
     void addTab();
     void onBeforeOpenContext();
     void onOpenContext();
-    void onTipOfDay();
     void saveDefaultState();
     void resetDefaultState();
     void overwriteBookmarkState();
