@@ -172,7 +172,8 @@ int main(int argc, char** argv)
 #ifdef SKG_WEBENGINE
     QApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
 #endif
-    auto m_widget = new SKGMainPanel(m_splash, &doc, argument);
+    auto m_widget = new SKGMainPanel(m_splash, &doc);
+    m_widget->processArguments(argument);
     m_widget->setUnifiedTitleAndToolBarOnMac(true);
     m_widget->show();
 
